pub struct SetCellVoltageTimeoutStruct {
pub timeout: u16,
}Expand description
Set the under-voltage timeout
Fields
timeout: u16If an individual cell exceeds the configured limit for this duration of time, the power will be locked-out