pub struct SetCurrentTimeoutStruct {
pub timeout: u16,
}Expand description
Set the over-current timeout
Fields
timeout: u16If the battery current exceeds the configured limit for this duration of time, the power will be locked-out