Struct bluerobotics_ping::bluebps::StateStruct
source · pub struct StateStruct {
pub battery_voltage: u16,
pub battery_current: u16,
pub battery_temperature: u16,
pub cpu_temperature: u16,
pub flags: u8,
pub cell_voltages_length: u8,
pub cell_voltages: Vec<u16>,
}Expand description
Get the current state of the device
Fields
battery_voltage: u16The main battery voltage
battery_current: u16The current measurement
battery_temperature: u16The battery temperature
cpu_temperature: u16The cpu temperature
flags: u8flags indicating if any of the configured limits are currently exceeded
cell_voltages_length: u8Array containing cell voltages
cell_voltages: Vec<u16>Trait Implementations
sourceimpl Clone for StateStruct
impl Clone for StateStruct
sourcefn clone(&self) -> StateStruct
fn clone(&self) -> StateStruct
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for StateStruct
impl Debug for StateStruct
sourceimpl Default for StateStruct
impl Default for StateStruct
sourcefn default() -> StateStruct
fn default() -> StateStruct
Returns the “default value” for a type. Read more
sourceimpl DeserializePayload for StateStruct
impl DeserializePayload for StateStruct
fn deserialize(payload: &[u8]) -> Self
sourceimpl MessageInfo for StateStruct
impl MessageInfo for StateStruct
sourceimpl PartialEq for StateStruct
impl PartialEq for StateStruct
sourcefn eq(&self, other: &StateStruct) -> bool
fn eq(&self, other: &StateStruct) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl SerializePayload for StateStruct
impl SerializePayload for StateStruct
impl StructuralPartialEq for StateStruct