Struct bluerobotics_ping::ping1d::DistanceStruct
source · pub struct DistanceStruct {
pub distance: u32,
pub confidence: u16,
pub transmit_duration: u16,
pub ping_number: u32,
pub scan_start: u32,
pub scan_length: u32,
pub gain_setting: u32,
}Expand description
The distance to target with confidence estimate. Relevant device parameters during the measurement are also provided.
Fields
distance: u32The current return distance determined for the most recent acoustic measurement.
confidence: u16Confidence in the most recent range measurement.
transmit_duration: u16The acoustic pulse length during acoustic transmission/activation.
ping_number: u32The pulse/measurement count since boot.
scan_start: u32The beginning of the scan region in mm from the transducer.
scan_length: u32The length of the scan region.
gain_setting: u32The current gain setting. 0: 0.6, 1: 1.8, 2: 5.5, 3: 12.9, 4: 30.2, 5: 66.1, 6: 144