pub struct OssProfileConfigurationStruct {
pub number_of_points: u16,
pub normalization_enabled: u8,
pub enhance_enabled: u8,
}Expand description
Get the profile output configuration. (Open source firmware only)
Fields
number_of_points: u16Not documented
normalization_enabled: u8If enabled, the profile data is scaled so that the maximum value aligns with the upper limit of 255. (0: Disabled, 1: Enabled)
enhance_enabled: u8If enabled, the profile data will be unevenly scaled to enhance peak values. (0: Disabled, 1: Enabled)