ProfileStruct

Struct ProfileStruct 

pub struct ProfileStruct {
    pub distance: u32,
    pub confidence: u16,
    pub transmit_duration: u16,
    pub ping_number: u32,
    pub scan_start: u32,
    pub scan_length: u32,
    pub gain_setting: u32,
    pub profile_data_length: u16,
    pub profile_data: Vec<u8>,
}
A profile produced from a single acoustic measurement. The data returned is an array of response strength at even intervals across the scan region. The scan region is defined as the region between <scan_start> and <scan_start + scan_length> millimeters away from the transducer. A distance measurement to the target is also provided.

Fields

distance: u32

The current return distance determined for the most recent acoustic measurement.

confidence: u16

Confidence in the most recent range measurement.

transmit_duration: u16

The acoustic pulse length during acoustic transmission/activation.

ping_number: u32

The pulse/measurement count since boot.

scan_start: u32

The beginning of the scan region in mm from the transducer.

scan_length: u32

The length of the scan region.

gain_setting: u32

The current gain setting. 0: 0.6, 1: 1.8, 2: 5.5, 3: 12.9, 4: 30.2, 5: 66.1, 6: 144

profile_data_length: u16

An array of return strength measurements taken at regular intervals across the scan region. The first element is the closest measurement to the sensor, and the last element is the farthest measurement in the scanned range.

profile_data: Vec<u8>