pub struct RangeStruct {
pub scan_start: u32,
pub scan_length: u32,
}Expand description
The scan range for acoustic measurements. Measurements returned by the device will lie in the range (scan_start, scan_start + scan_length).
Fields
scan_start: u32The beginning of the scan range in mm from the transducer.
scan_length: u32The length of the scan range.