AutoTransmitStruct

Struct AutoTransmitStruct 

pub struct AutoTransmitStruct {
    pub mode: u8,
    pub gain_setting: u8,
    pub transmit_duration: u16,
    pub sample_period: u16,
    pub transmit_frequency: u16,
    pub number_of_samples: u16,
    pub start_angle: u16,
    pub stop_angle: u16,
    pub num_steps: u8,
    pub delay: u8,
}
NEW (v1.1.0) Extended transducer message with auto-scan function. The sonar will automatically scan the region between start_angle and end_angle and send auto_device_data messages as soon as new data is available. Send a line break to stop scanning (and also begin the autobaudrate procedure). Alternatively, a motor_off message may be sent (but retries might be necessary on the half-duplex RS485 interface).

Fields

mode: u8

Operating mode (1 for Ping360)

gain_setting: u8

Analog gain setting (0 = low, 1 = normal, 2 = high)

transmit_duration: u16

Acoustic transmission duration (1~1000 us)

sample_period: u16

Time interval between individual signal intensity samples in 25 ns increments (80 to 40000 == 2 to 1000 us)

transmit_frequency: u16

Acoustic operating frequency (500~1000 kHz). It is only practical to use say 650 to 850 kHz due to the narrow bandwidth of the acoustic receiver.

number_of_samples: u16

Number of samples per reflected signal (supported values: 200~1200)

start_angle: u16

Head angle to begin scan sector for autoscan (0~399 = 0~360 degrees).

stop_angle: u16

Head angle to end scan sector for autoscan (0~399 = 0~360 degrees).

num_steps: u8

Number of 0.9 degree motor steps between pings for auto scan (1~10 = 0.9~9.0 degrees)

delay: u8

An additional delay between successive transmit pulses (0~100 ms). This may be necessary for some programs to avoid collisions on the RS485 USRT.