TransducerStruct

Struct TransducerStruct 

pub struct TransducerStruct {
    pub mode: u8,
    pub gain_setting: u8,
    pub angle: u16,
    pub transmit_duration: u16,
    pub sample_period: u16,
    pub transmit_frequency: u16,
    pub number_of_samples: u16,
    pub transmit: u8,
    pub reserved: u8,
}
The transducer will apply the commanded settings. The sonar will reply with a device_data message. If the transmit field is 0, the sonar will not transmit after locating the transducer, and the data field in the device_data message reply will be empty. If the transmit field is 1, the sonar will make an acoustic transmission after locating the transducer, and the resulting data will be uploaded in the data field of the device_data message reply. To allow for the worst case response time the command timeout should be set to 4000 msec.

Fields

mode: u8

Operating mode (1 for Ping360)

gain_setting: u8

Analog gain setting (0 = low, 1 = normal, 2 = high)

angle: u16

Head angle

transmit_duration: u16

Acoustic transmission duration (1~1000 us)

sample_period: u16

Time interval between individual signal intensity samples in 25 ns increments (80 to 40000 == 2 to 1000 us)

transmit_frequency: u16

Acoustic operating frequency (500~1000 kHz). It is only practical to use say 650 to 850 kHz due to the narrow bandwidth of the acoustic receiver.

number_of_samples: u16

Number of samples per reflected signal (supported values: 200~1200)

transmit: u8

0 = do not transmit; 1 = transmit after the transducer has reached the specified angle

reserved: u8

reserved