Struct bluerobotics_ping::bluebps::CellTimeoutStruct
source · pub struct CellTimeoutStruct {
pub timeout: u16,
}Expand description
Get the undervoltage timeout
Fields
timeout: u16If an individual cell exceeds the configured limit for this duration of time, the power will be locked-out