Struct bluerobotics_ping::message::ProtocolMessage

source ·
pub struct ProtocolMessage {
    pub payload_length: u16,
    pub message_id: u16,
    pub src_device_id: u8,
    pub dst_device_id: u8,
    pub payload: Vec<u8>,
    pub checksum: u16,
}

Fields

payload_length: u16message_id: u16src_device_id: u8dst_device_id: u8payload: Vec<u8>checksum: u16

Implementations

source

impl ProtocolMessage

source

pub fn new() -> Self

Message Format

Each message consists of a header, optional payload, and checksum. The binary format is specified as follows:

ByteTypeNameDescription
0u8start1Start frame identifier, ASCII ‘B’
1u8start2Start frame identifier, ASCII ‘R’
2-3u16payload_lengthNumber of bytes in payload.
4-5u16message_idThe message id.
6u8src_device_idThe device ID of the device sending the message.
7u8dst_device_idThe device ID of the intended recipient of the message.
8-nu8[]payloadThe message payload.
(n+1)-(n+2)u16checksumThe message checksum. The checksum is calculated as the sum of all the non-checksum bytes in the message.
source

pub fn set_message(&mut self, message: &impl PingMessage)

source

pub fn set_src_device_id(&mut self, src_device_id: u8)

source

pub fn dst_device_id(&self) -> u8

source

pub fn set_dst_device_id(&mut self, dst_device_id: u8)

source

pub fn payload(&self) -> &[u8]

source

pub fn checksum(&self) -> u16

source

pub fn update_checksum(&mut self)

source

pub fn calculate_crc(&self) -> u16

source

pub fn has_valid_crc(&self) -> bool

source

pub fn length(&self) -> usize

source

pub fn write(&self, writer: &mut dyn Write) -> Result<usize>

source

pub fn serialized(&self) -> Vec<u8>