Struct bluerobotics_ping::ping1d::ProfileStruct
source · pub struct ProfileStruct {
pub distance: u32,
pub confidence: u16,
pub transmit_duration: u16,
pub ping_number: u32,
pub scan_start: u32,
pub scan_length: u32,
pub gain_setting: u32,
pub profile_data_length: u16,
pub profile_data: Vec<u8>,
}Expand description
A profile produced from a single acoustic measurement. The data returned is an array of response strength at even intervals across the scan region. The scan region is defined as the region between <scan_start> and <scan_start + scan_length> millimeters away from the transducer. A distance measurement to the target is also provided.
Fields
distance: u32The current return distance determined for the most recent acoustic measurement.
confidence: u16Confidence in the most recent range measurement.
transmit_duration: u16The acoustic pulse length during acoustic transmission/activation.
ping_number: u32The pulse/measurement count since boot.
scan_start: u32The beginning of the scan region in mm from the transducer.
scan_length: u32The length of the scan region.
gain_setting: u32The current gain setting. 0: 0.6, 1: 1.8, 2: 5.5, 3: 12.9, 4: 30.2, 5: 66.1, 6: 144
profile_data_length: u16An array of return strength measurements taken at regular intervals across the scan region.
profile_data: Vec<u8>Trait Implementations
sourceimpl Clone for ProfileStruct
impl Clone for ProfileStruct
sourcefn clone(&self) -> ProfileStruct
fn clone(&self) -> ProfileStruct
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for ProfileStruct
impl Debug for ProfileStruct
sourceimpl Default for ProfileStruct
impl Default for ProfileStruct
sourcefn default() -> ProfileStruct
fn default() -> ProfileStruct
sourceimpl DeserializePayload for ProfileStruct
impl DeserializePayload for ProfileStruct
fn deserialize(payload: &[u8]) -> Self
sourceimpl PartialEq for ProfileStruct
impl PartialEq for ProfileStruct
sourcefn eq(&self, other: &ProfileStruct) -> bool
fn eq(&self, other: &ProfileStruct) -> bool
self and other values to be equal, and is used
by ==.