pub struct AutoDeviceDataStruct {}Expand description
NEW (v1.1.0) Extended version of device_data with auto_transmit information. The sensor emits this message when in auto_transmit mode.
Fields
mode: u8Operating mode (1 for Ping360)
gain_setting: u8Analog gain setting (0 = low, 1 = normal, 2 = high)
angle: u16Head angle
transmit_duration: u16Acoustic transmission duration (1~1000 us)
sample_period: u16Time interval between individual signal intensity samples in 25 ns increments (80 to 40000 == 2 to 1000 us)
transmit_frequency: u16Acoustic operating frequency (500~1000 kHz). It is only practical to use say 650 to 850 kHz due to the narrow bandwidth of the acoustic receiver.
start_angle: u16Head angle to begin scan sector for autoscan (0~399 = 0~360 degrees).
stop_angle: u16Head angle to end scan sector for autoscan (0~399 = 0~360 degrees).
num_steps: u8Number of 0.9 degree motor steps between pings for auto scan (1~10 = 0.9~9.0 degrees)
delay: u8An additional delay between successive transmit pulses (0~100 ms). This may be necessary for some programs to avoid collisions on the RS485 USRT.
number_of_samples: u16Number of samples per reflected signal (supported values: 200~1200)
data_length: u16An array of return strength measurements taken at regular intervals across the scan region. The first element is the closest measurement to the sensor, and the last element is the farthest measurement in the scanned range.
data: Vec<u8>Trait Implementations
Sourceimpl Clone for AutoDeviceDataStruct
impl Clone for AutoDeviceDataStruct
Sourcefn clone(&self) -> AutoDeviceDataStruct
fn clone(&self) -> AutoDeviceDataStruct
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more