Struct bluerobotics_ping::ping360::AutoDeviceDataStruct

source ·
pub struct AutoDeviceDataStruct {
Show 13 fields pub mode: u8, pub gain_setting: u8, pub angle: u16, pub transmit_duration: u16, pub sample_period: u16, pub transmit_frequency: u16, pub start_angle: u16, pub stop_angle: u16, pub num_steps: u8, pub delay: u8, pub number_of_samples: u16, pub data_length: u16, pub data: Vec<u8>,
}
Extended version of device_data with auto_transmit information. The sensor emits this message when in auto_transmit mode.

Fields

mode: u8

Operating mode (1 for Ping360)

gain_setting: u8

Analog gain setting (0 = low, 1 = normal, 2 = high)

angle: u16

Head angle

transmit_duration: u16

Acoustic transmission duration (1~1000 microseconds)

sample_period: u16

Time interval between individual signal intensity samples in 25nsec increments (80 to 40000 == 2 microseconds to 1000 microseconds)

transmit_frequency: u16

Acoustic operating frequency. Frequency range is 500kHz to 1000kHz, however it is only practical to use say 650kHz to 850kHz due to the narrow bandwidth of the acoustic receiver.

start_angle: u16

Head angle to begin scan sector for autoscan in gradians (0~399 = 0~360 degrees).

stop_angle: u16

Head angle to end scan sector for autoscan in gradians (0~399 = 0~360 degrees).

num_steps: u8

Number of 0.9 degree motor steps between pings for auto scan (1~10 = 0.9~9.0 degrees)

delay: u8

An additional delay between successive transmit pulses (0~100 ms). This may be necessary for some programs to avoid collisions on the RS485 USRT.

number_of_samples: u16

Number of samples per reflected signal

data_length: u16

8 bit binary data array representing sonar echo strength

data: Vec<u8>