Struct bluerobotics_ping::ping360::AutoDeviceDataStruct
source · pub struct AutoDeviceDataStruct {}Expand description
Extended version of device_data with auto_transmit information. The sensor emits this message when in auto_transmit mode.
Fields
mode: u8Operating mode (1 for Ping360)
gain_setting: u8Analog gain setting (0 = low, 1 = normal, 2 = high)
angle: u16Head angle
transmit_duration: u16Acoustic transmission duration (1~1000 microseconds)
sample_period: u16Time interval between individual signal intensity samples in 25nsec increments (80 to 40000 == 2 microseconds to 1000 microseconds)
transmit_frequency: u16Acoustic operating frequency. Frequency range is 500kHz to 1000kHz, however it is only practical to use say 650kHz to 850kHz due to the narrow bandwidth of the acoustic receiver.
start_angle: u16Head angle to begin scan sector for autoscan in gradians (0~399 = 0~360 degrees).
stop_angle: u16Head angle to end scan sector for autoscan in gradians (0~399 = 0~360 degrees).
num_steps: u8Number of 0.9 degree motor steps between pings for auto scan (1~10 = 0.9~9.0 degrees)
delay: u8An additional delay between successive transmit pulses (0~100 ms). This may be necessary for some programs to avoid collisions on the RS485 USRT.
number_of_samples: u16Number of samples per reflected signal
data_length: u168 bit binary data array representing sonar echo strength
data: Vec<u8>Trait Implementations
sourceimpl Clone for AutoDeviceDataStruct
impl Clone for AutoDeviceDataStruct
sourcefn clone(&self) -> AutoDeviceDataStruct
fn clone(&self) -> AutoDeviceDataStruct
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for AutoDeviceDataStruct
impl Debug for AutoDeviceDataStruct
sourceimpl Default for AutoDeviceDataStruct
impl Default for AutoDeviceDataStruct
sourcefn default() -> AutoDeviceDataStruct
fn default() -> AutoDeviceDataStruct
sourceimpl DeserializePayload for AutoDeviceDataStruct
impl DeserializePayload for AutoDeviceDataStruct
fn deserialize(payload: &[u8]) -> Self
sourceimpl PartialEq for AutoDeviceDataStruct
impl PartialEq for AutoDeviceDataStruct
sourcefn eq(&self, other: &AutoDeviceDataStruct) -> bool
fn eq(&self, other: &AutoDeviceDataStruct) -> bool
self and other values to be equal, and is used
by ==.