Struct bluerobotics_ping::ping360::DeviceDataStruct

source ·
pub struct DeviceDataStruct {
    pub mode: u8,
    pub gain_setting: u8,
    pub angle: u16,
    pub transmit_duration: u16,
    pub sample_period: u16,
    pub transmit_frequency: u16,
    pub number_of_samples: u16,
    pub data_length: u16,
    pub data: Vec<u8>,
}
This message is used to communicate the current sonar state. If the data field is populated, the other fields indicate the sonar state when the data was captured. The time taken before the response to the command is sent depends on the difference between the last angle scanned and the new angle in the parameters as well as the number of samples and sample interval (range). To allow for the worst case reponse time the command timeout should be set to 4000 msec.

Fields

mode: u8

Operating mode (1 for Ping360)

gain_setting: u8

Analog gain setting (0 = low, 1 = normal, 2 = high)

angle: u16

Head angle

transmit_duration: u16

Acoustic transmission duration (1~1000 us)

sample_period: u16

Time interval between individual signal intensity samples in 25 ns increments (80 to 40000 == 2 to 1000 us)

transmit_frequency: u16

Acoustic operating frequency (500~1000 kHz). It is only practical to use say 650 to 850 kHz due to the narrow bandwidth of the acoustic receiver.

number_of_samples: u16

Number of samples per reflected signal (supported values: 200~1200)

data_length: u16

An array of return strength measurements taken at regular intervals across the scan region. The first element is the closest measurement to the sensor, and the last element is the farthest measurement in the scanned range.

data: Vec<u8>