Struct bluerobotics_ping::ping360::ResetStruct

source ·
pub struct ResetStruct {
    pub bootloader: u8,
    pub reserved: u8,
}
Reset the sonar. The bootloader may run depending on the selection according to the bootloader payload field. When the bootloader runs, the external LED flashes at 5Hz. If the bootloader is not contacted within 5 seconds, it will run the current program. If there is no program, then the bootloader will wait forever for a connection. Note that if you issue a reset then you will have to close all your open comm ports and go back to issuing either a discovery message for UDP or go through the break sequence for serial comms before you can talk to the sonar again.

Fields

bootloader: u8

0 = skip bootloader; 1 = run bootloader

reserved: u8

reserved